#
# zshuper - pronounced as '/ʃ/uper'
#
# Edit config.zsh to configure zshuper
# Source this script like:
#  % source "${ZSHUPER_DIR}/"init.zsh
#

ZSHUPER_DIR="$(dirname "${_}")"

# PATH
export PATH="${PATH}:${HOME}/.local/share/bin:${HOME}/bin"

# Functions
source "${ZSHUPER_DIR}/functions/utils.zsh"

# Load config
source "${ZSHUPER_DIR}/config.zsh"

# Set up directories
source "${ZSHUPER_DIR}/modules/directories.zsh"

# Setup plugin manager
source "${ZSHUPER_DIR}/modules/pluginmanager.zsh"

case "${ZSHUPER_PLUGIN_MANAGER}" in;
    "antibody")
        source "${ZSHUPER_DIR}/modules/pluginmanager/antibody.zsh"
        ;;
    "zplug")
        source "${ZSHUPER_DIR}/modules/pluginmanager/zplug.zsh"
        ;;
    *)
        echo "Unknown plugin manager: '${ZSHUPER_PLUGIN_MANAGER}', plugins will not enable!"
esac

__zspr_plm_init

# Include own plugins
source "${ZSHUPER_DIR}/plugins.zsh"

# Load plugins
__zspr_plm_load_plugins

# Enable comments in interactive shell
setopt interactivecomments

# Show program exit code and don't check for jobs on exit
setopt printexitvalue
setopt nocheckjobs

# zshuper modules
source "${ZSHUPER_DIR}/modules/aliases.zsh"
source "${ZSHUPER_DIR}/modules/compinit.zsh"
source "${ZSHUPER_DIR}/modules/directories.zsh"
source "${ZSHUPER_DIR}/modules/editor.zsh"
source "${ZSHUPER_DIR}/modules/hastebin.zsh"
source "${ZSHUPER_DIR}/modules/history.zsh"
source "${ZSHUPER_DIR}/modules/terminal.zsh"
source "${ZSHUPER_DIR}/modules/new-scratch.zsh"
source "${ZSHUPER_DIR}/modules/pacman.zsh"
source "${ZSHUPER_DIR}/modules/rationalize-dot.zsh"
source "${ZSHUPER_DIR}/modules/new-scratch.zsh"
source "${ZSHUPER_DIR}/modules/use-zaw-search.zsh"

# Plugin configurations
source "${ZSHUPER_DIR}/modules/configurations/autosuggest.zsh"
